@@ -1,4 +1,5 @@
 import logging
+import math
 import socket
 
 import dask
@@ -20,7 +21,9 @@ if isinstance(FRAME_OFFLOAD_THRESHOLD, str):
     FRAME_OFFLOAD_THRESHOLD = parse_bytes(FRAME_OFFLOAD_THRESHOLD)
 
 
-async def to_frames(msg, serializers=None, on_error="message", context=None):
+async def to_frames(
+    msg, serializers=None, on_error="message", context=None, allow_offload=True
+):
     """
     Serialize a message into a list of Distributed protocol frames.
     """
@@ -37,17 +40,25 @@ async def to_frames(msg, serializers=None, on_error="message", context=None):
             logger.exception(e)
             raise
 
-    if FRAME_OFFLOAD_THRESHOLD and sizeof(msg) > FRAME_OFFLOAD_THRESHOLD:
+    if FRAME_OFFLOAD_THRESHOLD and allow_offload:
+        try:
+            msg_size = sizeof(msg)
+        except RecursionError:
+            msg_size = math.inf
+    else:
+        msg_size = 0
+
+    if allow_offload and FRAME_OFFLOAD_THRESHOLD and msg_size > FRAME_OFFLOAD_THRESHOLD:
         return await offload(_to_frames)
     else:
         return _to_frames()
 
 
-async def from_frames(frames, deserialize=True, deserializers=None):
+async def from_frames(frames, deserialize=True, deserializers=None, allow_offload=True):
     """
     Unserialize a list of Distributed protocol frames.
     """
-    size = sum(map(nbytes, frames))
+    size = False
 
     def _from_frames():
         try:
@@ -63,7 +74,14 @@ async def from_frames(frames, deserialize=True, deserializers=None):
             logger.error("truncated data stream (%d bytes): %s", size, datastr)
             raise
 
-    if deserialize and FRAME_OFFLOAD_THRESHOLD and size > FRAME_OFFLOAD_THRESHOLD:
+    if allow_offload and deserialize and FRAME_OFFLOAD_THRESHOLD:
+        size = sum(map(nbytes, frames))
+    if (
+        allow_offload
+        and deserialize
+        and FRAME_OFFLOAD_THRESHOLD
+        and size > FRAME_OFFLOAD_THRESHOLD
+    ):
         res = await offload(_from_frames)
     else:
         res = _from_frames()
