@@ -1219,7 +1219,7 @@ async def test_service_hosts():
             assert sock.getsockname()[0] == "127.0.0.1"
 
 
-@gen_cluster(client=True, worker_kwargs={"profile_cycle_interval": 100})
+@gen_cluster(client=True, worker_kwargs={"profile_cycle_interval": "100ms"})
 async def test_profile_metadata(c, s, a, b):
     start = time() - 1
     futures = c.map(slowinc, range(10), delay=0.05, workers=a.address)
@@ -1234,7 +1234,28 @@ async def test_profile_metadata(c, s, a, b):
     assert not meta["counts"][-1][1]
 
 
-@gen_cluster(client=True, worker_kwargs={"profile_cycle_interval": 100})
+@gen_cluster(client=True, worker_kwargs={"profile_cycle_interval": "100ms"})
+async def test_profile_metadata_timeout(c, s, a, b):
+    start = time() - 1
+
+    def raise_timeout(*args, **kwargs):
+        raise TimeoutError
+
+    b.handlers["profile_metadata"] = raise_timeout
+
+    futures = c.map(slowinc, range(10), delay=0.05, workers=a.address)
+    await wait(futures)
+    await asyncio.sleep(0.200)
+
+    meta = await s.get_profile_metadata(profile_cycle_interval=0.100)
+    now = time() + 1
+    assert meta
+    assert all(start < t < now for t, count in meta["counts"])
+    assert all(0 <= count < 30 for t, count in meta["counts"][:4])
+    assert not meta["counts"][-1][1]
+
+
+@gen_cluster(client=True, worker_kwargs={"profile_cycle_interval": "100ms"})
 async def test_profile_metadata_keys(c, s, a, b):
     x = c.map(slowinc, range(10), delay=0.05)
     y = c.map(slowdec, range(10), delay=0.05)
@@ -1247,6 +1268,42 @@ async def test_profile_metadata_keys(c, s, a, b):
     )
 
 
+@gen_cluster(
+    client=True,
+    config={
+        "distributed.worker.profile.interval": "1ms",
+        "distributed.worker.profile.cycle": "100ms",
+    },
+)
+async def test_statistical_profiling(c, s, a, b):
+    futures = c.map(slowinc, range(10), delay=0.1)
+
+    await wait(futures)
+
+    profile = await s.get_profile()
+    assert profile["count"]
+
+
+@gen_cluster(
+    client=True,
+    config={
+        "distributed.worker.profile.interval": "1ms",
+        "distributed.worker.profile.cycle": "100ms",
+    },
+)
+async def test_statistical_profiling_failure(c, s, a, b):
+    futures = c.map(slowinc, range(10), delay=0.1)
+
+    def raise_timeout(*args, **kwargs):
+        raise TimeoutError
+
+    b.handlers["profile"] = raise_timeout
+    await wait(futures)
+
+    profile = await s.get_profile()
+    assert profile["count"]
+
+
 @gen_cluster(client=True)
 async def test_cancel_fire_and_forget(c, s, a, b):
     x = delayed(slowinc)(1, delay=0.05)
